@@ -29,14 +29,37 @@ impl FPUState {
 	}
 }
 
-pub fn generate_random_number() -> Option<u32> {
+pub fn generate_random_number32() -> Option<u32> {
 	None
 }
 
+pub fn generate_random_number64() -> Option<u64> {
+	None
+}
+
+pub fn run_on_hypervisor() -> bool {
+	true
+}
+
+/// Search the most significant bit
+#[inline(always)]
+pub fn msb(value: u64) -> Option<u64> {
+	if value > 0 {
+		let ret: u64;
+		let u64_bits = 64;
+		unsafe {
+			llvm_asm!("clz $0, $1; sub $0, $2, $0" : "=r"(ret) : "r"(value), "r"(u64_bits - 1) : "cc" : "volatile");
+		}
+		Some(ret)
+	} else {
+		None
+	}
+}
+
 /// The halt function stops the processor until the next interrupt arrives
 pub fn halt() {
 	unsafe {
-		asm!("wfi" :::: "volatile");
+		llvm_asm!("wfi" :::: "volatile");
 	}
 }
 
@@ -64,6 +87,10 @@ pub fn get_timestamp() -> u64 {
 	0
 }
 
+pub fn supports_1gib_pages() -> bool {
+	false
+}
+
 /// Delay execution by the given number of microseconds using busy-waiting.
 #[inline]
 pub fn udelay(usecs: u64) {
