@@ -291,29 +291,26 @@ impl CpuFrequency {
 	}
 
 	unsafe fn detect_from_cpuid_brand_string(&mut self, cpuid: &CpuId) -> Result<(), ()> {
-		let extended_function_info = cpuid
-			.get_extended_function_info()
-			.expect("CPUID Extended Function Info not available!");
-		let brand_string = extended_function_info
-			.processor_brand_string()
-			.expect("CPUID Brand String not available!");
+		if let Some(processor_brand) = cpuid.get_processor_brand_string() {
+			let brand_string = processor_brand.as_str();
+			let ghz_find = brand_string.find("GHz");
 
-		let ghz_find = brand_string.find("GHz");
-		if let Some(ghz_find) = ghz_find {
-			let index = ghz_find - 4;
-			let thousand_char = brand_string.chars().nth(index).unwrap();
-			let decimal_char = brand_string.chars().nth(index + 1).unwrap();
-			let hundred_char = brand_string.chars().nth(index + 2).unwrap();
-			let ten_char = brand_string.chars().nth(index + 3).unwrap();
+			if let Some(ghz_find) = ghz_find {
+				let index = ghz_find - 4;
+				let thousand_char = brand_string.chars().nth(index).unwrap();
+				let decimal_char = brand_string.chars().nth(index + 1).unwrap();
+				let hundred_char = brand_string.chars().nth(index + 2).unwrap();
+				let ten_char = brand_string.chars().nth(index + 3).unwrap();
 
-			if let (Some(thousand), '.', Some(hundred), Some(ten)) = (
-				thousand_char.to_digit(10),
-				decimal_char,
-				hundred_char.to_digit(10),
-				ten_char.to_digit(10),
-			) {
-				let mhz = (thousand * 1000 + hundred * 100 + ten * 10) as u16;
-				return self.set_detected_cpu_frequency(mhz, CpuFrequencySources::CpuIdTscInfo);
+				if let (Some(thousand), '.', Some(hundred), Some(ten)) = (
+					thousand_char.to_digit(10),
+					decimal_char,
+					hundred_char.to_digit(10),
+					ten_char.to_digit(10),
+				) {
+					let mhz = (thousand * 1000 + hundred * 100 + ten * 10) as u16;
+					return self.set_detected_cpu_frequency(mhz, CpuFrequencySources::CpuIdTscInfo);
+				}
 			}
 		}
 
@@ -447,7 +444,7 @@ impl fmt::Display for CpuFrequency {
 struct CpuFeaturePrinter {
 	feature_info: FeatureInfo,
 	extended_feature_info: ExtendedFeatures,
-	extended_function_info: ExtendedFunctionInfo,
+	extend_processor_identifiers: ExtendedProcessorFeatureIdentifiers,
 }
 
 impl CpuFeaturePrinter {
@@ -459,9 +456,9 @@ impl CpuFeaturePrinter {
 			extended_feature_info: cpuid
 				.get_extended_feature_info()
 				.expect("CPUID Extended Feature Info not available!"),
-			extended_function_info: cpuid
-				.get_extended_function_info()
-				.expect("CPUID Extended Function Info not available!"),
+			extend_processor_identifiers: cpuid
+				.get_extended_processor_and_feature_identifiers()
+				.expect("Extended Processor and Processor Feature Identifiers not available"),
 		}
 	}
 }
@@ -519,7 +516,7 @@ impl fmt::Display for CpuFeaturePrinter {
 		if self.feature_info.has_vmx() {
 			write!(f, "VMX ")?;
 		}
-		if self.extended_function_info.has_rdtscp() {
+		if self.extend_processor_identifiers.has_rdtscp() {
 			write!(f, "RDTSCP ")?;
 		}
 		if self.feature_info.has_monitor_mwait() {
@@ -718,18 +715,17 @@ pub fn detect_features() {
 	let extended_feature_info = cpuid
 		.get_extended_feature_info()
 		.expect("CPUID Extended Feature Info not available!");
-	let extended_function_info = cpuid
-		.get_extended_function_info()
-		.expect("CPUID Extended Function Info not available!");
+	let processor_capacity_info = cpuid
+		.get_processor_capacity_feature_info()
+		.expect("Processor Capacity Parameters and Extended Feature Identification not available!");
+	let extend_processor_identifiers = cpuid
+		.get_extended_processor_and_feature_identifiers()
+		.expect("Extended Processor and Processor Feature Identifiers not available");
 
 	unsafe {
-		PHYSICAL_ADDRESS_BITS = extended_function_info
-			.physical_address_bits()
-			.expect("CPUID Physical Address Bits not available!");
-		LINEAR_ADDRESS_BITS = extended_function_info
-			.linear_address_bits()
-			.expect("CPUID Linear Address Bits not available!");
-		SUPPORTS_1GIB_PAGES = extended_function_info.has_1gib_pages();
+		PHYSICAL_ADDRESS_BITS = processor_capacity_info.physical_address_bits();
+		LINEAR_ADDRESS_BITS = processor_capacity_info.linear_address_bits();
+		SUPPORTS_1GIB_PAGES = extend_processor_identifiers.has_1gib_pages();
 		SUPPORTS_AVX = feature_info.has_avx();
 		SUPPORTS_RDRAND = feature_info.has_rdrand();
 		SUPPORTS_TSC_DEADLINE = feature_info.has_tsc_deadline();
@@ -738,7 +734,7 @@ pub fn detect_features() {
 		RUN_ON_HYPERVISOR = feature_info.has_hypervisor();
 		SUPPORTS_FSGS = extended_feature_info.has_fsgsbase();
 
-		if extended_function_info.has_rdtscp() {
+		if extend_processor_identifiers.has_rdtscp() {
 			TIMESTAMP_FUNCTION = get_timestamp_rdtscp;
 		}
 
@@ -852,15 +848,11 @@ pub fn print_information() {
 	infoheader!(" CPU INFORMATION ");
 
 	let cpuid = CpuId::new();
-	let extended_function_info = cpuid
-		.get_extended_function_info()
-		.expect("CPUID Extended Function Info not available!");
-	let brand_string = extended_function_info
-		.processor_brand_string()
-		.expect("CPUID Brand String not available!");
 	let feature_printer = CpuFeaturePrinter::new(&cpuid);
 
-	infoentry!("Model", brand_string);
+	if let Some(brand_string) = cpuid.get_processor_brand_string() {
+		infoentry!("Model", brand_string.as_str());
+	}
 
 	unsafe {
 		infoentry!("Frequency", CPU_FREQUENCY);
