@@ -115,67 +115,67 @@ pub trait SyscallInterface: Send + Sync {
 	}
 
 	fn get_mac_address(&self) -> Result<[u8; 6], ()> {
-		#[cfg(feature = "pci")]
+		#[cfg(all(feature = "pci", not(target_arch = "aarch64")))]
 		match arch::kernel::pci::get_network_driver() {
 			Some(driver) => Ok(driver.lock().get_mac_address()),
 			_ => Err(()),
 		}
-		#[cfg(not(feature = "pci"))]
+		#[cfg(not(all(feature = "pci", not(target_arch = "aarch64"))))]
 		Err(())
 	}
 
 	fn get_mtu(&self) -> Result<u16, ()> {
-		#[cfg(feature = "pci")]
+		#[cfg(all(feature = "pci", not(target_arch = "aarch64")))]
 		match arch::kernel::pci::get_network_driver() {
 			Some(driver) => Ok(driver.lock().get_mtu()),
 			_ => Err(()),
 		}
-		#[cfg(not(feature = "pci"))]
+		#[cfg(not(all(feature = "pci", not(target_arch = "aarch64"))))]
 		Err(())
 	}
 
 	fn has_packet(&self) -> bool {
-		#[cfg(feature = "pci")]
+		#[cfg(all(feature = "pci", not(target_arch = "aarch64")))]
 		match arch::kernel::pci::get_network_driver() {
 			Some(driver) => driver.lock().has_packet(),
 			_ => false,
 		}
-		#[cfg(not(feature = "pci"))]
+		#[cfg(not(all(feature = "pci", not(target_arch = "aarch64"))))]
 		false
 	}
 
 	fn get_tx_buffer(&self, len: usize) -> Result<(*mut u8, usize), ()> {
-		#[cfg(feature = "pci")]
+		#[cfg(all(feature = "pci", not(target_arch = "aarch64")))]
 		match arch::kernel::pci::get_network_driver() {
 			Some(driver) => driver.lock().get_tx_buffer(len),
 			_ => Err(()),
 		}
-		#[cfg(not(feature = "pci"))]
+		#[cfg(not(all(feature = "pci", not(target_arch = "aarch64"))))]
 		Err(())
 	}
 
 	fn send_tx_buffer(&self, handle: usize, len: usize) -> Result<(), ()> {
-		#[cfg(feature = "pci")]
+		#[cfg(all(feature = "pci", not(target_arch = "aarch64")))]
 		match arch::kernel::pci::get_network_driver() {
 			Some(driver) => driver.lock().send_tx_buffer(handle, len),
 			_ => Err(()),
 		}
-		#[cfg(not(feature = "pci"))]
+		#[cfg(not(all(feature = "pci", not(target_arch = "aarch64"))))]
 		Err(())
 	}
 
 	fn receive_rx_buffer(&self) -> Result<(&'static [u8], usize), ()> {
-		#[cfg(feature = "pci")]
+		#[cfg(all(feature = "pci", not(target_arch = "aarch64")))]
 		match arch::kernel::pci::get_network_driver() {
 			Some(driver) => driver.lock().receive_rx_buffer(),
 			_ => Err(()),
 		}
-		#[cfg(not(feature = "pci"))]
+		#[cfg(not(all(feature = "pci", not(target_arch = "aarch64"))))]
 		Err(())
 	}
 
 	fn rx_buffer_consumed(&self, handle: usize) -> Result<(), ()> {
-		#[cfg(feature = "pci")]
+		#[cfg(all(feature = "pci", not(target_arch = "aarch64")))]
 		match arch::kernel::pci::get_network_driver() {
 			Some(driver) => {
 				driver.lock().rx_buffer_consumed(handle);
@@ -183,7 +183,7 @@ pub trait SyscallInterface: Send + Sync {
 			}
 			_ => Err(()),
 		}
-		#[cfg(not(feature = "pci"))]
+		#[cfg(not(all(feature = "pci", not(target_arch = "aarch64"))))]
 		Err(())
 	}
 
